@@ -6,18 +6,19 @@ from typing import TYPE_CHECKING, Any, Awaitable, Callable, List, Optional, Type
 
 from robotcode.core.logging import LoggingDescriptor
 from robotcode.core.lsp.types import InlayHint, InlayHintKind, Range
-from robotcode.language_server.common.decorators import language_id
-from robotcode.language_server.common.text_document import TextDocument
-from robotcode.language_server.robotframework.configuration import InlayHintsConfig
-from robotcode.language_server.robotframework.diagnostics.library_doc import KeywordArgumentKind, KeywordDoc, LibraryDoc
-from robotcode.language_server.robotframework.diagnostics.namespace import Namespace
-from robotcode.language_server.robotframework.utils.ast_utils import Token, range_from_node, range_from_token
-from robotcode.language_server.robotframework.utils.async_ast import iter_nodes
+
+from ...common.decorators import language_id
+from ...common.text_document import TextDocument
+from ..configuration import InlayHintsConfig
+from ..diagnostics.library_doc import KeywordArgumentKind, KeywordDoc, LibraryDoc
+from ..diagnostics.namespace import Namespace
+from ..utils.ast_utils import Token, range_from_node, range_from_token
+from ..utils.async_ast import iter_nodes
 
 if TYPE_CHECKING:
-    from robotcode.language_server.robotframework.protocol import RobotLanguageServerProtocol
+    from ..protocol import RobotLanguageServerProtocol
 
-from .model_helper import ModelHelperMixin
+from ..diagnostics.model_helper import ModelHelperMixin
 from .protocol_part import RobotLanguageServerProtocolPart
 
 _HandlerMethod = Callable[
@@ -38,7 +39,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
         if folder is None:
             return None
 
-        return await self.parent.workspace.get_configuration(InlayHintsConfig, folder.uri)
+        return await self.parent.workspace.get_configuration_async(InlayHintsConfig, folder.uri)
 
     def _find_method(self, cls: Type[Any]) -> Optional[_HandlerMethod]:
         if cls is ast.AST:
@@ -171,7 +172,7 @@ class RobotInlayHintProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMix
                     )
 
         if keyword_token is not None and config.namespaces:
-            lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
+            lib_entry, kw_namespace = await self.get_namespace_info_from_keyword_token(namespace, keyword_token)
             if lib_entry is None and kw_namespace is None:
                 if kw_doc.libtype == "LIBRARY":
                     lib = next(
